﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using HoldemHand;

namespace PokerChancenRechner
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        //Kartenwerte und dazugehörige Bezeichnungen für die Poker-Library
        private Dictionary<string, string> cards = new Dictionary<string, string>() 
        { 
            {"2", "2"}, {"3", "3"}, {"4", "4"}, {"5", "5"}, {"6", "6"}, {"7", "7"},
            {"8", "8"}, {"9", "9"}, {"10", "10"}, {"Bube", "J"}, {"Dame", "Q"}, 
            {"König", "K"}, { "Ass", "A" }
        };

        //Kartenfarben und dazugehörige Bezeichnungen für die Poker-Library
        private Dictionary<string, string> colors = new Dictionary<string, string>()
        { 
            {"Pik", "s"}, {"Herz", "h"}, {"Karo", "d"}, {"Kreuz", "c"}
        };

        private void Form1_Load(object sender, EventArgs e)
        {
            //Kartenbezeichnungen, -farben und Stapel in die Listboxen laden
            listBoxCard.Items.AddRange(cards.Select(x => x.Key).ToArray());
            listBoxColor.Items.AddRange(colors.Select(x => x.Key).ToArray());
            listBoxStack.Items.AddRange(new string[]{"Hand", "Deck"});
        }

        private void buttonAddCard_Click(object sender, EventArgs e)
        {
            //Überprüfe, ob Kartenwert, -farbe und der Zielstapel
            //ausgewählt wurden
            if (listBoxCard.SelectedItems.Count != 1 ||
                listBoxColor.SelectedItems.Count != 1 ||
                listBoxStack.SelectedItems.Count != 1)
            {
                MessageBox.Show("Bitte Karte, Farbe und Stack wählen.");
            }
            else
            {
                //Überprüfe ob der Zielstapel schon voll ist
                if ((listBoxDeck.Items.Count == 3 && listBoxStack.SelectedItem.ToString() == "Deck") ||
                    (listBoxHand.Items.Count == 2 && listBoxStack.SelectedItem.ToString() == "Hand"))
                {
                    MessageBox.Show("Maximale Kartenanzahl erreicht. Anderen Stack wählen oder zurücksetzen.");
                }
                else
                {
                    //Füge die Karte dem Zielstapel hinzu
                    if (listBoxStack.SelectedItem.ToString() == "Deck")
                    {
                        listBoxDeck.Items.Add(listBoxCard.SelectedItem.ToString() + "-" + listBoxColor.SelectedItem.ToString());
                    }
                    else
                    {
                        listBoxHand.Items.Add(listBoxCard.SelectedItem.ToString() + "-" + listBoxColor.SelectedItem.ToString());
                    }
                }
            }
        }

        private void buttonReset_Click(object sender, EventArgs e)
        {
            //Leere die Zielstapel um eine neue Berechnung zu ermöglichen
            listBoxHand.Items.Clear();
            listBoxDeck.Items.Clear();
        }

        private void buttonCalculate_Click(object sender, EventArgs e)
        {
            //Überprüfe, ob beide Zielstapel ausreichend belegt sind
            if (listBoxHand.Items.Count != 2 ||
                listBoxDeck.Items.Count != 3)
            {
                MessageBox.Show("Bitte geben Sie erst die Hand und das Deck an.");
            }
            else
            {
                //Fasse alle Hand-Karten als string in der Poker-Library-Syntax zusammen
                string handCards = "";
                foreach (var item in listBoxHand.Items)
                {
                    handCards += cards[item.ToString().Split('-')[0]]
                              + colors[item.ToString().Split('-')[1]]
                              + " ";
                }
                handCards = handCards.Trim();

                //Fasse alle Deck-Karten als string in der Poker-Library-Syntax zusammen
                string deckCards = "";
                foreach (var item in listBoxDeck.Items)
                {
                    deckCards += cards[item.ToString().Split('-')[0]]
                              + colors[item.ToString().Split('-')[1]]
                              + " ";
                }
                deckCards = deckCards.Trim();

                //Initialisiere Hilfsvariablen für die Poker-Library
                double[] self = new double[9];
                double[] opponent = new double[9];
                double selfWin = 0.0;

                //Berechne Poker-Hände und Wahrscheinlichkeiten
                Hand.HandPlayerOpponentOdds(handCards, deckCards, ref self, ref opponent);

                //Berechne Sieg-/Split-Wahrscheinlichkeit
                for (int i = 0; i < 9; i++)
                {
                    selfWin += self[i] * 100.0;             
                }

                //Gebe Sieg-/Split-Wahrscheinlichkeit aus
                labelChance.Text = string.Format("{0:##0.0}%", selfWin);
            }
        }
    }
}

